Models Module
=============

The models module provides the core infrastructure modeling components including dynamics, costs, budgets, hierarchy, and metadata models.

Base Models
-----------

.. automodule:: infralib.models.base
   :members:
   :undoc-members:
   :show-inheritance:

Dynamics Models
---------------

.. automodule:: infralib.models.dynamics
   :members:
   :undoc-members:
   :show-inheritance:

Cost Models
-----------

.. automodule:: infralib.models.cost
   :members:
   :undoc-members:
   :show-inheritance:

Budget Models
-------------

.. automodule:: infralib.models.budget
   :members:
   :undoc-members:
   :show-inheritance:

Hierarchy Models
----------------

.. automodule:: infralib.models.hierarchy
   :members:
   :undoc-members:
   :show-inheritance:

Metadata Models
---------------

.. automodule:: infralib.models.metadata
   :members:
   :undoc-members:
   :show-inheritance:
